/* **********************************************************************************************************
 *	Das Modul beinhaltet Event Listener fr die Behandlung der Keyboard Eingaben
 *	in die Datums- und Uhrzeit Eingabefelder, Daylight Savings Time, Zeitzone, Lngen-
 *	und Breitengrad.
 *
 *	Jedes Objekt hat 3 Eventlistener fr "keydown", "keyup" und "change". Dazu gehren 
 *	dann bei "keydown" und "change" jeweils eine Callback Funktion und bei "keydown" das
 *	setzen einer Variablen. SIEHE DIE BESCHREIBUNG DER LISTENER. Die Funktionen
 *	sind in Keyboard.js definiert.
 *
 *
 *	The module includes event listener for handling keyboard input
 *	in the date and time input fields, Daylight Savings Time, Time Zone, Longitude
 *	and latitude.
 *
 *	Each object has 3 event listers for keydown, keyup and change.  These include: 
 *	then with keydown and change each a callback function and with keydown the
 *	set a variable.  SEEHE  DESCRIPTION  THE LISTENER.The functions
 *	are defined in Keyboard.js.
 *
 *
 *	Events der Objekte:
 *	---------------------------
 *
 *	-	objB {body}										-	Globalen Tastendruck im Body abfangen (Button Berechnen,
 *																	Bild Mondphase)
 *																	To intercept global keystroke in the body (Calculate button,
 *																	picture moon phase)
 *	-	objDay{Eingabe Tag}						-	Tastatureingabe des Tages
 *																	Keyboard input of the day
 *	-	objMonth{Eingabe Monat}					-	Tastatureingabe des Monats
 *																	Keyboard input of the month
 *	-	objYear{Eingabe Tag}						-	Tastatureingabe des Jahres
 *																	Keyboard input of the year
 *	-	objDST{Eingabe Sommer/Winter}		-	Tastatureingabe des Tages
 *																	Keyboard input of the day
 *	-	objTZ{Eingabe Zeitzone}					-	Tastatureingabe der Zeitzone
 *																	Keyboard input of the time zone
 *	-	objLongitude{Eingabe Lngengrad}	-	Tastatureingabe des Lngengrades
 *																	Keyboard input of the longitude
 *	-	objLatitude{Eingabe Breitengrad}		-	Tastatureingabe des Breitengrades
 *																	Keyboard input of the latitude
 *
 *
 *	25.04.2021, Dieter Steffan
 *	25.05.2021, Dieter Steffan						Update Beschreibungen
 *
 *********************************************************************************** ****************************/



// Tastaturevent im Body global abfangen um Buttons bedienen zu knnen.
// Intercept keyboard event in the body globally to be able to operate buttons.
objB.addEventListener("keydown",  function(e){
	// Tastendruck "b" - Press "b"
	if(e.which == 66){
		// Die Callback Funktion des in Keyboard.js definierten Listener aufrufen.
		// Call the callback function of the listener defined in Keyboard. js
		// Simuliert den Klick auf den "Berechnen" Button
		// Simulates the click on the "Calculate" button
		bodyBerechnenClick(e, ".calc");
	}// Tastendruck "p" - Press "p"
	else if(e.which == 80){
		bodyMoonPositionClick(e, ".phasepicture");
	}// Tastendruck "Enter" - Press "Enter"
	else if(e.which == 13){
		// Startet das Programm - starts the program
		bodyBerechnenClick(e, ".calc");
	}
	// Fokus auf das Hauptprogramm.
	objB.focus();
});
					

					
/* ********************************************************************************** */

					
// Tag Tastaturanschlge Erlauben/Verbieten und erster.
// Tag Keystrokes Allow/Forbid and first.
objDay.addEventListener("keydown",  function (e) {
	keydownInputDay(e);
});	
// Test beim Verlassen des Textfeldes.
// Test when leaving the text field.
objDay.addEventListener("change", function(){
	keydownChangeDay(objDay, objMonth, objLeapYear);
});
					
// Der Listener wird aufgerufen, wenn bei der Tageseingabe
// eine Taste losgelassen wird ...
// The listener is called up when a key is released during the day entry ...
objDay.addEventListener("keyup", function (e){
	// ... und wenn es eine der Sondertasten Shift, Strg, Alt ist,
	// dann setze die Variable fr die verbotenen Sondertasten zurck.
	// . . . and if it is one of the special keys Shift, Ctrl, Alt,
	// then reset the variable for the forbidden special keys.
	if (e.which >= SHIFTLEFT && e.which <= ALTLEFT){
		deniedKeyDay = false;
	}
});


/* ********************************************************************************** */

					
// Tag Tastaturanschlge Erlauben/Verbieten und erster.
// Tag Keystrokes Allow/Forbid and first.
objMonth.addEventListener("keydown",  function (e) {
	keydownInputMonth(e);
});	
// Test beim Verlassen des Textfeldes.
// Test when leaving the text field.
objMonth.addEventListener("change", function(){
	keydownChangeMonth(objMonth);
});
					
// Der Listener wird aufgerufen, wenn bei der Tageseingabe
// eine Taste losgelassen wird ...
// The listener is called up when a key is released during the day entry ...
objMonth.addEventListener("keyup", function (e){
	// ... und wenn es eine der Sondertasten Shift, Strg, Alt ist,
	// dann setze die Variable fr die verbotenen Sondertasten zurck.
	// . . . and if it is one of the special keys Shift, Ctrl, Alt,
	// then reset the variable for the forbidden special keys.
	if (e.which >= SHIFTLEFT && e.which <= ALTLEFT){
		deniedKeyDay = false;
	}
});


/* ********************************************************************************** */

					
// JahrTastaturanschlge Erlauben/Verbieten und erster.
// Year Keystrokes Allow/Forbid and first.
objYear.addEventListener("keydown",  function (e) {
	keydownInputYear(e);
});	
// Test beim Verlassen des Textfeldes.
// Test when leaving the text field.
objYear.addEventListener("change", function(){
	keydownChangeYear(objYear, objLeapYear);
});
				
// Der Listener wird aufgerufen, wenn bei der Jahreseingabe
// eine Taste losgelassen wird ...
// The listener is called up when a key is released during the year entry ...
objYear.addEventListener("keyup", function (e){
	// ... und wenn es eine der Sondertasten Shift, Strg, Alt ist,
	// dann setze die Variable fr die verbotenen Sondertasten zurck.
	// . . . and if it is one of the special keys Shift, Ctrl, Alt,
	// then reset the variable for the forbidden special keys.
	if (e.which >= SHIFTLEFT && e.which <= ALTLEFT){
		deniedKeyYear = false;
	}
});


/* ********************************************************************************** */

								
// Daylight Savings Time Tastaturanschlge Erlauben/Verbieten und erster.
// Daylight Savings Time Keystrokes Allow/Forbid and first.
objDST.addEventListener("keydown", function (e){
	keydownInputDST(e);
});	
// Test beim Verlassen des Textfeldes.
// Test when leaving the text field.
objDST.addEventListener("change", function(){
	keydownChangeDST(objDST);
});
					
// Der Listener wird aufgerufen, wenn bei der Eingabe der Sommer/Winterzeit
// eine Taste losgelassen wird ...
// The listener is called up when a key is released during the dalight savings time entry ...
objDST.addEventListener("keyup", function (e){
	// ... und wenn es eine der Sondertasten Shift, Strg, Alt ist,
	// dann setze die Variable fr die verbotenen Sondertasten zurck.
	// . . . and if it is one of the special keys Shift, Ctrl, Alt,
	// then reset the variable for the forbidden special keys.
	if (e.which >= SHIFTLEFT && e.which <= ALTLEFT){
		deniedKeyDST = false;
	}
});

				
/* ********************************************************************************** */


// Timezone Tastaturanschlge Erlauben/Verbieten und erster.
// Timezone Keystrokes Allow/Forbid and first.
objTZ.addEventListener("keydown", function (e) {
	keydownInputTZ(e);
});

// Test beim Verlassen des Textfeldes.
// Test when leaving the text field.
objTZ.addEventListener("change", function() {
	keydownChangeTZ(objTZ);
});
					
// Der Listener wird aufgerufen, wenn bei der Eingabe der zeitzone
// eine Taste losgelassen wird ...
// The listener is called up when a key is released during the timezone entry ...
objTZ.addEventListener("keyup", function (e) {
	// ... und wenn es eine der Sondertasten Shift, Strg, Alt ist,
	// dann setze die Variable fr die verbotenen Sondertasten zurck.
	// . . . and if it is one of the special keys Shift, Ctrl, Alt,
	// then reset the variable for the forbidden special keys.
	if (e.which >= SHIFTLEFT && e.which <= ALTLEFT){
		deniedKeyTZ = false;
	}
});

					
/* ********************************************************************************** */

						
// Lngengrad Tastaturanschlge Erlauben/Verbieten und erster.
// Longitude Keystrokes Allow/Forbid and first.
objLongitude.addEventListener("keydown", function (e){
	keydownInputLongitude(e);
});

// Test beim Verlassen des Textfeldes.
// Test when leaving the text field.
objLongitude.addEventListener("change", function(){
	keydownChangeLongitude(objLongitude);
});
					
// Der Listener wird aufgerufen, wenn bei der Eingabe des Lngengrads
// eine Taste losgelassen wird ...
// The listener is called up when a key is released during the longitude entry ...
objLongitude.addEventListener("keyup", function (e){
	// ... und wenn es eine der Sondertasten Shift, Strg, Alt ist,
	// dann setze die Variable fr die verbotenen Sondertasten zurck.
	// . . . and if it is one of the special keys Shift, Ctrl, Alt,
	// then reset the variable for the forbidden special keys.
	if (e.which >= SHIFTLEFT && e.which <= ALTLEFT){
		deniedKeyLONGITUDE = false;
	}
});


/* ********************************************************************************** */


/* ********************************************************************************** */
						
// Breitengrad Tastaturanschlge Erlauben/Verbieten und erster.
// Latitude Keystrokes Allow/Forbid and first.
objLatitude.addEventListener("keydown", function (e) {
	keydownInputLatitude(e);
});

// Test beim Verlassen des Textfeldes.
// Test when leaving the text field.
objLatitude.addEventListener("change", function(){
	keydownChangeLatitude(objLatitude);
});
					
// Der Listener wird aufgerufen, wenn bei der Eingabe des Breitengrads
// eine Taste losgelassen wird ...
// The listener is called up when a key is released during the latitude entry ...
objLatitude.addEventListener("keyup", function (e){
	// ... und wenn es eine der Sondertasten Shift, Strg, Alt ist,
	// dann setze die Variable fr die verbotenen Sondertasten zurck.
	// . . . and if it is one of the special keys Shift, Ctrl, Alt,
	// then reset the variable for the forbidden special keys.
	if (e.which >= SHIFTLEFT && e.which <= ALTLEFT){
		deniedKeyLATITUDE = false;
	}
});
